# CerealTest (WIP)

This tool automates serial tests via a JSON configuration file where you specify port settings and the array of tests that will be run.

You can specify the message to send as text or as hexadecimal data,  expected answer via a regular expression, or you can set a Python script to compute the message to send as well as a reception script that can process the answer for maximum flexibility.


## Contributions
This repository is open to contributions, however code must be compatible with Python 3.8, the latest version that runs on Windows 7.
